Release Notes — Pootle 2.9.0b4 documentation

# Release Notes

The following are release notes used on PyPI and mailing lists for Pootle releases.

These are the changes that have happened in Pootle and may affect your server. Also be aware of the important changes in the Translate Toolkit as many of these also affect Pootle.

If you are upgrading Pootle, you might want to see some tips to ensure your upgrade goes smoothly.

## Upcoming releases

### 2.9 release

- Pootle 2.9 release notes

## Final releases

### 2.8 series

- 2.8.1
- 2.8.0

### 2.7 series

- 2.7.6
- 2.7.5
- 2.7.4
- 2.7.3
- 2.7.2
- 2.7.1
- 2.7.0

### 2.6 series

- 2.6.4
- 2.6.3
- 2.6.2
- 2.6.1
- 2.6.0

### 2.5 series

- 2.5.1.3
- 2.5.1.2
- 2.5.1.1
- 2.5.1
- 2.5.0

### 2.1 series

- 2.1.6
- 2.1.5
- 2.1.4
- 2.1.3
- 2.1.2
- 2.1.1

### Older releases

- 0.10 to 2.1